==> xoonips-3.32.tar.gz: xoonips-3.32/xoonips/admin/actions/system_rss_update.php <==
<?php
// $Revision: 1.1.2.5 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();

// check token ticket
require_once( '../class/base/gtickets.php' );
$ticket_area = 'xoonips_admin_system_rss';
if ( ! $xoopsGTicket->check( true, $ticket_area, false ) ) {
  redirect_header( $xoonips_admin['mypage_url'], 3, $xoopsGTicket->getErrors() );
  exit();
}

// get requests
$post_keys = array(
  'rss_file_path' => array( 's', false, true ),
  'rss_item_max' => array( 'i', false, true ),
);
$post_vals = xoonips_admin_get_requests( 'post', $post_keys );

// set config keys
$config_keys = array();
foreach ( $post_keys as $key => $attributes ) {
  list( $data_type, $is_array, $required ) = $attributes;
  $config_keys[$key] = $data_type;
}

// load xoonips session for xnpGenerateRSS()
include_once '../include/lib.php';
include_once '../include/create_session.php';
xnp_load_init_create_session();

// check values
$config_vals = xoonips_admin_get_configs( $config_keys, 'n' );
// rss file path
if ( preg_match( '/(\.\.|^\/)/', $post_vals['rss_file_path'] ) ){
  redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_ERROR_SYSTEM_RSS_RSS_FILE_PATH_PARENT_DIR );
  exit();
}
if ( $config_vals['rss_file_path'] != $post_vals['rss_file_path'] ){
  if ( ! xnpGenerateRSS( XOOPS_ROOT_PATH.'/'.$post_vals['rss_file_path'] ) ) {
    redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_ERROR_SYSTEM_RSS_RSS_FILE_PATH_NOT_WRITABLE );
    exit();
   }
}
xoonips_admin_set_config( 'rss_file_path', $post_vals['rss_file_path'], 's' );

// rss item max
if ( $post_vals['rss_item_max'] < 0 )
  $post_vals['rss_item_max'] = 0;
if ( $config_vals['rss_item_max'] != $post_vals['rss_item_max'] ) {
  if ( ! xnpGenerateRSS( XOOPS_ROOT_PATH.'/'.$post_vals['rss_file_path'], $post_vals['rss_item_max'] ) ) {
    redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_ERROR_SYSTEM_RSS_RSS_FILE_PATH_NOT_WRITABLE );
  }
}
xoonips_admin_set_config( 'rss_item_max', $post_vals['rss_item_max'], 'i' );

redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_MSG_DBUPDATED );

?>

==> xoonips-3.41.tar.gz: xoonips-3.41/xoonips/admin/actions/system_rss_update.php <==
<?php
// $Revision: 1.1.4.1.2.4 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
if ( ! defined( 'XOOPS_ROOT_PATH' ) ) {
  exit();
}

// check token ticket
require_once( '../class/base/gtickets.php' );
$ticket_area = 'xoonips_admin_system_rss';
if ( ! $xoopsGTicket->check( true, $ticket_area, false ) ) {
  redirect_header( $xoonips_admin['mypage_url'], 3, $xoopsGTicket->getErrors() );
  exit();
}

// get requests
$post_keys = array(
  'rss_item_max' => array(
    'i',
    false,
    true,
  ),
);
$post_vals = xoonips_admin_get_requests( 'post', $post_keys );

// set config keys
$config_keys = array();
foreach ( $post_keys as $key => $attributes ) {
  list( $data_type, $is_array, $required ) = $attributes;
  $config_keys[$key] = $data_type;
}

// check values
$config_vals = xoonips_admin_get_configs( $config_keys, 'n' );

// rss item max
if ( $post_vals['rss_item_max'] < 0 ) {
  $post_vals['rss_item_max'] = 0;
}
xoonips_admin_set_config( 'rss_item_max', $post_vals['rss_item_max'], 'i' );

redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_MSG_DBUPDATED );

?>
